/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.utils;

import org.wso2.registry.RegistryException;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.secure.SecureRegistry;
import org.wso2.usermanager.Realm;
import org.wso2.usermanager.UserManagerException;

import javax.servlet.http.HttpServletRequest;

public class UserUtil {

    public static boolean isAdmin(HttpServletRequest request, String userName) throws RegistryException {

        if (RegistryConstants.ADMIN_USER.equals(userName)) {
            return true;
        }

        SecureRegistry secureRegistry = CommonUtil.getUserRegistry(request);
        Realm userRealm = secureRegistry.getUserRealm();

        String[] roles = new String[0];
        try {
            roles = userRealm.getUserStoreReader().getUserRoles(userName);
        } catch (UserManagerException e) {
            String msg = "Could not get the roles of the user: " + userName;
            throw new RegistryException(msg);
        }

        return containsString(RegistryConstants.ADMIN_ROLE, roles);
    }

    private static boolean containsString(String value, String[] sArray) {

        for (int i = 0; i < sArray.length; i++) {
            if (sArray[i].equals(value)) {
                return true;
            }
        }

        return false;
    }
}
